@charset "utf-8";

/*
Hive Appier Framework
Copyright (c) 2008-2017 Hive Solutions Lda.

This file is part of Hive Appier Framework.

Hive Appier Framework is free software: you can redistribute it and/or modify
it under the terms of the Apache License as published by the Apache
Foundation, either version 2.0 of the License, or (at your option) any
later version.

Hive Appier Framework is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
Apache License for more details.

You should have received a copy of the Apache License along with
Hive Appier Framework. If not, see <http://www.apache.org/licenses/>.
*/

/*
__author__    = João Magalhães <joamag@hive.pt>
__version__   = 1.0.0
__revision__  = $LastChangedRevision$
__date__      = $LastChangedDate$
__copyright__ = Copyright (c) 2008-2017 Hive Solutions Lda.
__license__   = Apache License, Version 2.0
*/

.balloon {
    display: inline-block;
}

.balloon > .baloon-icon {
    cursor: pointer;
    transition: color 0.10s ease-in;
    -o-transition: color 0.10s ease-in;
    -ms-transition: color 0.10s ease-in;
    -moz-transition: color 0.10s ease-in;
    -webkit-transition: color 0.10s ease-in;
}

.balloon > .baloon-icon:hover {
    color: #3668c6;
    cursor: pointer;
}

body.flat .balloon > .baloon-icon:hover {
    color: #257f96;
}

.balloon > .balloon-contents {
    animation: fade-in 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -o-animation: fade-in0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -ms-animation: fade-in 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -moz-animation: fade-in 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -webkit-animation: fade-in 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    animation-delay: 1s;
    background-color: #fafafa;
    border: 1px solid #cccccc;
    box-shadow: 0px 1px 4px #dddddd;
    -moz-box-shadow: 0px 1px 4px #dddddd;
    -webkit-box-shadow: 0px 1px 4px #dddddd;
    display: none;
    font-size: 13px;
    font-weight: normal;
    line-height: 20px;
    margin-top: 8px;
    max-width: 300px;
    padding: 10px 12px 10px 12px;
    position: absolute;
    text-transform: none;
}

body.flat .balloon > .balloon-contents {
    animation: fade-into-drop 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -o-animation: fade-into-drop 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -ms-animation: fade-into-drop 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -moz-animation: fade-into-drop 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    -webkit-animation: fade-into-drop 0.25s 0.5s cubic-bezier(0.645, 0.045, 0.355, 1.0) forwards;
    border-radius: 5px 5px 5px 5px;
    -moz-border-radius: 5px 5px 5px 5px;
    -webkit-border-radius: 5px 5px 5px 5px;
    box-shadow: none;
    -moz-box-shadow: none;
    -webkit-box-shadow: none;
    font-weight: 600;
    opacity: 0.0;
}

.balloon:hover > .balloon-contents {
    display: block;
}

.panel-model {
    border: 1px solid #e0e0e0;
    margin: 24px 0px 24px 0px;
    padding: 0px 0px 0px 0px;
    width: 690px;
}

.panel-model h3 {
    background-color: #f0f0f0;
    border-bottom: 1px solid #e0e0e0;
    font-size: 14px;
    margin: 0px 0px 0px 0px;
    padding: 14px 16px 14px 16px;
    text-transform: uppercase;
}

.panel-model ul {
    margin: 0px 0px 0px 0px;
}

.panel-model ul li {
    margin: 0px 0px 0px 0px;
    padding: 12px 16px 12px 16px;
}

.panel-model ul li:hover {
    background-color: inherit;
}

.panel-model ul li .button {
    font-size: 13px;
}

.panel-model ul li .left {
    float: left;
}

.panel-model ul li .right {
    float: right;
}

.pages {
    font-size: 0px;
    font-weight: bold;
    padding: 32px 0px 32px 0px;
    text-align: center;
}

body.flat .pages {
    font-weight: 600;
}

.pages > .page {
    border-bottom: 1px solid #cccccc;
    border-left: 1px solid #cccccc;
    border-top: 1px solid #cccccc;
    display: inline-block;
    font-size: 14px;
    margin: 0px 0px 0px 0px;
    padding: 4px 10px 4px 10px;
}

body.flat .pages > .page {
    font-size: 13px;
}

.pages > .page:first-child {
    border-radius: 4px 0px 0px 4px;
    -moz-border-radius: 4px 0px 0px 4px;
    -webkit-border-radius: 4px 0px 0px 4px;
}

.pages > .page:last-child {
    border-radius: 0px 4px 4px 0px;
    -moz-border-radius: 0px 4px 4px 0px;
    -webkit-border-radius: 0px 4px 4px 0px;
    border-right: 1px solid #cccccc;
}

.pages > .page:hover {
    background-color: #f2f2f2;
}

.pages > .page.selected {
    background-color: #888888;
    border-color: #888888;
    color: #ffffff;
}

.pages > .page.disabled {
    color: #aaaaaa;
}

.pages > .page.disabled:hover {
    background-color: #ffffff;
}

.pages > a.page {
    color: #4d4d4d;
}

.header-message .message-contents {
    background-color: #cee6c5;
    border: 1px solid #86c795;
    color: #4d4d4d;
    cursor: pointer;
    font-weight: bold;
    height: 30px;
    line-height: 30px;
    margin: -17px auto -15px auto;
    text-align: center;
    width: 300px;
}

body.flat .header-message .message-contents {
    font-weight: 600;
}

.header-message.error .message-contents {
    background-color: #fcc0c0;
    border-color: #f68f8f;
}
